==> jc-1.4.0.tar.gz: javax/swing/plaf/ComponentInputMapUIResource.h <==
// public class javax.swing.plaf.ComponentInputMapUIResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ec5882550c1f0cdd javax_swing_ComponentInputMap
// @dep_class 790c4e1b642750d1 javax_swing_InputMap
// @dep_class 5d27b508d3c3ecaa javax_swing_plaf_ComponentInputMapUIResource

// header file dependencies
// @dep_header javax_swing_ComponentInputMap

#include "javax/swing/ComponentInputMap.h"

#ifndef _JC_javax_swing_plaf_ComponentInputMapUIResource_H_
#define _JC_javax_swing_plaf_ComponentInputMapUIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_ComponentInputMapUIResource$sub_refs	_jc_javax_swing_plaf_ComponentInputMapUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_ComponentInputMapUIResource$sub_nonrefs	_jc_javax_swing_plaf_ComponentInputMapUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_ComponentInputMapUIResource$refs	_jc_javax_swing_plaf_ComponentInputMapUIResource$refs;
typedef struct _jc_javax_swing_plaf_ComponentInputMapUIResource$nonrefs	_jc_javax_swing_plaf_ComponentInputMapUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_ComponentInputMapUIResource$object	_jc_javax_swing_plaf_ComponentInputMapUIResource$object;

typedef const struct _jc_javax_swing_plaf_ComponentInputMapUIResource$vmethods	_jc_javax_swing_plaf_ComponentInputMapUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_ComponentInputMapUIResource$vtable	_jc_javax_swing_plaf_ComponentInputMapUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_ComponentInputMapUIResource$vtype	_jc_javax_swing_plaf_ComponentInputMapUIResource$vtype;

// Constructors
extern void _jc_javax_swing_plaf_ComponentInputMapUIResource$method$_init$f0371e99ef84354a(_jc_env *, struct _jc_javax_swing_plaf_ComponentInputMapUIResource$object *, struct _jc_javax_swing_JComponent$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_InputMap$vmethods	javax_swing_InputMap;
	_jc_javax_swing_ComponentInputMap$vmethods	javax_swing_ComponentInputMap;
	_jc_javax_swing_plaf_ComponentInputMapUIResource$vmethods	javax_swing_plaf_ComponentInputMapUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_ComponentInputMapUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$refs {
    _jc_javax_swing_plaf_ComponentInputMapUIResource$sub_refs	javax_swing_plaf_ComponentInputMapUIResource;
    _jc_javax_swing_ComponentInputMap$sub_refs	javax_swing_ComponentInputMap;
    _jc_javax_swing_InputMap$sub_refs	javax_swing_InputMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_InputMap$sub_nonrefs	javax_swing_InputMap;
    _jc_javax_swing_ComponentInputMap$sub_nonrefs	javax_swing_ComponentInputMap;
    _jc_javax_swing_plaf_ComponentInputMapUIResource$sub_nonrefs	javax_swing_plaf_ComponentInputMapUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$object {
	_jc_javax_swing_plaf_ComponentInputMapUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_ComponentInputMapUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_ComponentInputMapUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_ComponentInputMapUIResource$vtype _jc_javax_swing_plaf_ComponentInputMapUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_ComponentInputMapUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_ComponentInputMapUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_ComponentInputMapUIResource_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/ComponentInputMapUIResource.h <==
// public class javax.swing.plaf.ComponentInputMapUIResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ec5882550c1f0cdd javax_swing_ComponentInputMap
// @dep_class 790c4e1b642750d1 javax_swing_InputMap
// @dep_class 5d27b508d3c3ecaa javax_swing_plaf_ComponentInputMapUIResource

// header file dependencies
// @dep_header javax_swing_ComponentInputMap

#include "javax/swing/ComponentInputMap.h"

#ifndef _JC_javax_swing_plaf_ComponentInputMapUIResource_H_
#define _JC_javax_swing_plaf_ComponentInputMapUIResource_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_ComponentInputMapUIResource$sub_refs	_jc_javax_swing_plaf_ComponentInputMapUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_ComponentInputMapUIResource$sub_nonrefs	_jc_javax_swing_plaf_ComponentInputMapUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_ComponentInputMapUIResource$refs	_jc_javax_swing_plaf_ComponentInputMapUIResource$refs;
typedef struct _jc_javax_swing_plaf_ComponentInputMapUIResource$nonrefs	_jc_javax_swing_plaf_ComponentInputMapUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_ComponentInputMapUIResource$object	_jc_javax_swing_plaf_ComponentInputMapUIResource$object;

typedef const struct _jc_javax_swing_plaf_ComponentInputMapUIResource$vmethods	_jc_javax_swing_plaf_ComponentInputMapUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_ComponentInputMapUIResource$vtable	_jc_javax_swing_plaf_ComponentInputMapUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_ComponentInputMapUIResource$vtype	_jc_javax_swing_plaf_ComponentInputMapUIResource$vtype;

// Constructors
extern void _jc_javax_swing_plaf_ComponentInputMapUIResource$method$_init$f0371e99ef84354a(_jc_env *, struct _jc_javax_swing_plaf_ComponentInputMapUIResource$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_InputMap$vmethods	javax_swing_InputMap;
	_jc_javax_swing_ComponentInputMap$vmethods	javax_swing_ComponentInputMap;
	_jc_javax_swing_plaf_ComponentInputMapUIResource$vmethods	javax_swing_plaf_ComponentInputMapUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_ComponentInputMapUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$refs {
    _jc_javax_swing_plaf_ComponentInputMapUIResource$sub_refs	javax_swing_plaf_ComponentInputMapUIResource;
    _jc_javax_swing_ComponentInputMap$sub_refs	javax_swing_ComponentInputMap;
    _jc_javax_swing_InputMap$sub_refs	javax_swing_InputMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_InputMap$sub_nonrefs	javax_swing_InputMap;
    _jc_javax_swing_ComponentInputMap$sub_nonrefs	javax_swing_ComponentInputMap;
    _jc_javax_swing_plaf_ComponentInputMapUIResource$sub_nonrefs	javax_swing_plaf_ComponentInputMapUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_ComponentInputMapUIResource$object {
	_jc_javax_swing_plaf_ComponentInputMapUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_ComponentInputMapUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_ComponentInputMapUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_ComponentInputMapUIResource$vtype _jc_javax_swing_plaf_ComponentInputMapUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_ComponentInputMapUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_ComponentInputMapUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_ComponentInputMapUIResource_H_ */
